# Generated by Django 4.1.1 on 2022-12-13 17:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('menu', '0003_menu_is_new_alter_menu_link'),
    ]

    operations = [
        migrations.AlterField(
            model_name='menu',
            name='menu_group',
            field=models.ManyToManyField(blank=True, related_name='menu_group_menu', to='menu.menugroup'),
        ),
    ]
